/* DOMContentLoaded is fired once the document has been loaded and parsed,
   but without waiting for other external resources to load (css/images/etc)
   That makes the app more responsive and perceived as faster.
   https://developer.mozilla.org/Web/Reference/Events/DOMContentLoaded
*/
window.addEventListener('DOMContentLoaded', function() {
    /* We'll ask the browser to use strict code to help us catch errors earlier.
       https://developer.mozilla.org/Web/JavaScript/Reference/Functions_and_function_scope/Strict_mode */
    "use strict";
    
    var translate = navigator.mozL10n.get;
    
    /* We want to wait until the localisations library has loaded all the strings.
       So we'll tell it to let us know once it's ready. */
    navigator.mozL10n.once(start);
    
    function start() {
	var message = document.getElementById('message');
	/* We're using textContent because inserting content from external sources
	   into your page using innerHTML can be dangerous.
	   https://developer.mozilla.org/Web/API/Element.innerHTML#Security_considerations */
	message.textContent = translate('message');

	/* Dice selected */
	var dice = "1d6";  // default selection
	document.form.select.addEventListener('change', function(e) {
	    dice = e.target.value;
	    var nb = dice.split(/(\d+)d(\d+)/)[1]; // nb dice
	    var faces = dice.split(/(\d+)d(\d+)/)[2];  // nb faces
	    
	    document.getElementById("dice-result").innerHTML = '';
	    for (var n=0; n < nb; n++) {
		document.getElementById("dice-result").innerHTML += '<img src="img/D'+faces+'.svg" width="80">';
	    }
	});
	/* Roll the dice */
	document.form.button.addEventListener('click', function(e) { 
	    dice_roll(dice); 
	});
    }
});

/* Roll dice (http://www.devasp.net/net/articles/display/618.html)
 */
function dice_roll(dice) {
    /* Parse dice => nb dice, nb faces, operation */
    var nb = dice.split(/(\d+)d(\d+)/)[1]; // nb dice
    var faces = dice.split(/(\d+)d(\d+)/)[2];  // nb faces
    var op = dice.split(/(\d+)d(\d+)/)[0];  // operation (+=sum, C=concat, F=fudge)

    /* Roll the dice and store results */
    var rolls = [];
    document.getElementById("dice-result").innerHTML = '';
    for (var n=0; n < nb; n++) {
	rolls.push(Math.round(Math.random() * faces) % faces + 1);
	document.getElementById("dice-result").innerHTML += '<img src="img/D'+faces+'.svg" width="80">';
    }
    console.log("roll(" + nb + "d" + faces + ")= " + rolls);

    /* Compute results */
    navigator.vibrate(50);
    document.getElementById("dice-result").innerHTML += '<p id="result"></p>';
    var res = "";
    switch (op) {
    case "+":  // sum dice
	res = rolls.reduce(function(a, b) { return a + b; }, 0);
	break;
    case "C":  // concat dice
	for (var i=0; i<rolls.length; i++) {
	    rolls[i] = rolls[i] % faces;
	}
	res = rolls.join("");
	break;
    case "F":  // fudge dice
	for (var i=0; i<rolls.length; i++) {
	    if (rolls[i] <= 2) {
		rolls[i] = "-";
	    }
	    else if (rolls[i] >= 5) {
		rolls[i] = "+";
	    }
	    else {
		rolls[i] = "0";
	    }
	}
	res = rolls.join(" ");
	break;
    case "S":  // Shadowrun success rolls
	var success = 0;
	for (var i=0; i<rolls.length; i++) {
	    if(rolls[i] >= 5) success++;  // count d6 >= 5
	}
	res = success + " " + (success > 1? "hits": "hit");
	break;
    default:  // separate results
	res = rolls.join(" - ");
    }
    /* And display */
    document.getElementById("result").innerHTML = res;
}
